Jackmcbarn has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/161669

Change subject: Improve mod_security warning
......................................................................

Improve mod_security warning

Make it detect mod_security2 as well, and make the warning message
scarier.

Bug: 39463
Change-Id: Ic8dbd8425299f60e9fc0b54ff1b9a9a991d24190
---
M includes/installer/Installer.php
M includes/installer/i18n/en.json
2 files changed, 4 insertions(+), 3 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/core 
refs/changes/69/161669/1

diff --git a/includes/installer/i18n/en.json b/includes/installer/i18n/en.json
index 1e1c2da..4857495 100644
--- a/includes/installer/i18n/en.json
+++ b/includes/installer/i18n/en.json
@@ -70,7 +70,7 @@
        "config-apc": "[http://www.php.net/apc APC] is installed",
        "config-wincache": "[http://www.iis.net/download/WinCacheForPhp 
WinCache] is installed",
        "config-no-cache": "<strong>Warning:</strong> Could not find 
[http://www.php.net/apc APC], [http://xcache.lighttpd.net/ XCache] or 
[http://www.iis.net/download/WinCacheForPhp WinCache].\nObject caching is not 
enabled.",
-       "config-mod-security": "<strong>Warning:</strong> Your web server has 
[http://modsecurity.org/ mod_security] enabled. If misconfigured, it can cause 
problems for MediaWiki or other software that allows users to post arbitrary 
content.\nRefer to [http://modsecurity.org/documentation/ mod_security 
documentation] or contact your host's support if you encounter random errors.",
+       "config-mod-security": "<strong>Warning:</strong> Your web server has 
[http://modsecurity.org/ mod_security]/mod_security2 enabled. Many common 
configurations of this will cause problems for MediaWiki and other software 
that allows users to post arbitrary content.\nIf possible, this should be 
disabled. Otherwise, refer to [http://modsecurity.org/documentation/ 
mod_security documentation] or contact your host's support if you encounter 
random errors.",
        "config-diff3-bad": "GNU diff3 not found.",
        "config-git": "Found the Git version control software: 
<code>$1</code>.",
        "config-git-bad": "Git version control software not found.",

diff --git a/includes/installer/Installer.php b/includes/installer/Installer.php
index f84ed00..d333355 100644
--- a/includes/installer/Installer.php
+++ b/includes/installer/Installer.php
@@ -898,11 +898,12 @@
        }
 
        /**
         * Scare user to death if they have mod_security
         * @return bool
         */
        protected function envCheckModSecurity() {
-               if ( self::apacheModulePresent( 'mod_security' ) ) {
+               if ( self::apacheModulePresent( 'mod_security' )
+                       || self::apacheModulePresent( 'mod_security2' ) ) {
                        $this->showMessage( 'config-mod-security' );
                }
 
@@ -898,11 +898,12 @@
 
        /**
-        * Scare user to death if they have mod_security
+        * Scare user to death if they have mod_security or mod_security2
         * @return bool
         */
-- 
To view, visit https://gerrit.wikimedia.org/r/161669
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Ic8dbd8425299f60e9fc0b54ff1b9a9a991d24190
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/core
Gerrit-Branch: master
Gerrit-Owner: Jackmcbarn <jackmcb...@gmail.com>

_______________________________________________
MediaWiki-commits mailing list
MediaWiki-commits@lists.wikimedia.org
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to